@@ -170,8 +170,12 @@ int main( int i_argc, char **pp_argv )
         i_program = strtol( pp_argv[2], NULL, 0 );
 
     p_pat_dvbpsi_fd = dvbpsi_AttachPAT( PATCallback, NULL );
+    if ( p_pat_dvbpsi_fd == NULL )
+        goto out;
 
     p_buffer = malloc( TS_SIZE * READ_ONCE );
+    if ( p_buffer == NULL )
+        goto out;
 
     for ( ; ; )
     {
@@ -195,7 +199,10 @@ int main( int i_argc, char **pp_argv )
             i_ts_read++;
         }
     }
+    free( p_buffer );
 
+out:
+    if ( p_pat_dvbpsi_fd ) dvbpsi_DetachPAT( p_pat_dvbpsi_fd );
     close( i_fd );
     fprintf( stderr, "no PAT/PMT found\n" );
 
